@@ -25,8 +25,6 @@ class Matcher(Preprocessor):
   Optional: output and output_format arguments to write results to file.
   Supported formats are "csv", "xlsx", "json", and "html".
   '''
-
-
   def __init__(self,
                query,
                proteome,
@@ -183,7 +181,7 @@ class Matcher(Preprocessor):
     # compile all matches into format used for benchmarking (comma separated)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', ''))
+        all_matches.append((peptide, '', '', '', '', '', ''))
       for match in matches:
         # retrieve protein IDs from the other created table
         get_protein_data = 'SELECT * FROM "{names_table}" WHERE protein_number = "{protein_number}"'.format(
@@ -380,7 +378,7 @@ class Matcher(Preprocessor):
     # (peptide, matched peptide, protein matched in, index, # of mismatches)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', ''))
+        all_matches.append((peptide, '', '', '', '', '', ''))
       else:
         for match in matches:
           all_matches.append((
